BitmapBucketIteratorSource

Trait BitmapBucketIteratorSource 

pub trait BitmapBucketIteratorSource<'a>: Clone + 'a {
    type Iter: Iterator<Item = BucketItem> + 'a;

    // Required method
    fn scan_bucket_iter(
        &self,
        dimension_key: Vec<u8>,
        range: Range<u64>,
        direction: ScanDirection,
    ) -> Self::Iter;
}
Storage backend that can scan one bitmap dimension key synchronously.

This is for request-local backends such as RocksDB, where the bucket scan naturally owns or borrows a synchronous iterator. The iterator evaluator is fully synchronous so these iterators can stay on the blocking task that owns them.

Required Associated Types

type Iter: Iterator<Item = BucketItem> + 'a

Required Methods

fn scan_bucket_iter( &self, dimension_key: Vec<u8>, range: Range<u64>, direction: ScanDirection, ) -> Self::Iter

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors